@@ -1,7 +1,10 @@
 import os
-from jinjaql.factory import Snaql
+from jinjaql.factory import JinJAQL
 import jinjaql.engine as engine
+import pathlib
 import pandas as pd
+import pyodbc
+import timeit
 
 def nwt_engine(query_string: str, connection_string: str):
     """
@@ -17,14 +20,19 @@ def nwt_engine(query_string: str, connection_string: str):
     finally:
         connection.close()
 
-sql_root = os.path.abspath(os.path.dirname(__file__))
+sql_root = pathlib.Path(r'C:\Users\david.smit\PycharmProjects\jinjaql\jinjaql\tests\queries')
 
-snaql = Snaql(sql_root, 'queries', engine=engine.pandas)
+snaql = JinJAQL(sql_root, engine=nwt_engine, cache=True)
 
 gkn_queries = snaql.load_queries('GKN_query.sql')
 context = {
     'database':'C1_RDM',
     'station':'View_Station440',
+    'top':100,
 }
-result = gkn_queries.top_ten(**context)
-print(result)
+
+def test_query():
+    gkn_queries.top_ten(**context)
+
+total_time = timeit.timeit(test_query, number=5)
+print(total_time)
\ No newline at end of file
